@@ -5,14 +5,18 @@ use warnings;
 package Sub::MultiMethod;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.005';
+our $VERSION   = '0.006';
 
 use B ();
 use Exporter::Shiny qw( multimethod multimethods_from_roles monomethod );
-use Sub::Util ();
 use Type::Params ();
 use Types::Standard -types;
 
+*_set_subname =
+	eval { require Sub::Util;  \&Sub::Util::set_subname } ||
+	eval { require Sub::Name;  \&Sub::Name::subname }     ||
+	do   { sub { pop } } ;
+
 our %CANDIDATES;
 our %DISPATCHERS;
 our $DECLARATION_ORDER = 0;
@@ -164,7 +168,7 @@ sub install_candidate {
 				? 'Type::Params::compile_named_oo'
 				: 'Type::Params::compile',
 		);
-		my $coderef = Sub::Util::set_subname(
+		my $coderef = _set_subname(
 			"$target\::$aliases[0]",
 			eval($code)||die($@),
 		);
@@ -231,6 +235,10 @@ sub install_dispatcher {
 	
 	eval "$code; 1" or die($@);
 	
+	exists &mro::get_linear_isa
+		or eval { require mro }
+		or do { require MRO::Compat };
+	
 	my $coderef = do {
 		no strict 'refs';
 		\&{"$target\::$sub_name"};
@@ -252,7 +260,7 @@ sub dispatch {
 	
 	# Figure out which packages to consider when finding candidates.
 	my @packages = $is_method
-		? do { require MRO::Compat; @{ mro::get_linear_isa($pkg) } }
+		? @{ mro::get_linear_isa($pkg) }
 		: $pkg;
 	my $curr_height = @packages;
 	
